@@ -1,15 +1,18 @@
 `ordispider` <-
     function (ord, groups, display = "sites", w = weights(ord, display),
-              spiders = c("centroid", "median"),
-              show.groups, label = FALSE, ...)
+              spiders = c("centroid", "median"), show.groups,
+              label = FALSE, col = NULL, lty = NULL, lwd = NULL, ...)
 {
     weights.default <- function(object, ...) NULL
     spiders <- match.arg(spiders)
     if (inherits(ord, "cca") && missing(groups)) {
         lc <- scores(ord, display = "lc", ...)
         wa <- scores(ord, display = "wa", ...)
+        if (is.null(col))
+            col <- par("fg")
         ordiArgAbsorber(lc[, 1], lc[, 2], wa[, 1], wa[, 2],
-                        FUN = segments, ...)
+                        FUN = segments, col = col, lty = lty, lwd = lwd,
+                        ...)
         class(lc) <- "ordispider"
         return(invisible(lc))
     }
@@ -36,8 +39,20 @@
         warning("weights are ignored with 'median' spiders")
     out <- seq(along = groups)
     inds <- names(table(groups))
-    if (label) 
+    if (label)
     cntrs <- names <- NULL
+
+    ## fill in graphical vectors with default values if unspecified
+    ## and recycles shorter vectors
+    for(arg in c("col","lty","lwd")) {
+        tmp <- mget(arg,ifnotfound=list(NULL))[[1]]
+        if(is.null(tmp))
+            tmp <- ifelse(suppressWarnings(is.null(par(arg))),
+                          par("fg"), par(arg))
+        if(length(inds) != length(tmp))
+            tmp <- rep_len(tmp, length(inds))
+        assign(arg, tmp)
+    }
     ## 'kk' removes NA scores and NA groups
     kk <- complete.cases(pts) & !is.na(groups)
     for (is in inds) {
@@ -50,7 +65,9 @@
                               "centroid" = apply(X, 2, weighted.mean, w = W),
                               "median" = ordimedian(X, rep(1, nrow(X))))
                 ordiArgAbsorber(ave[1], ave[2], X[, 1], X[, 2],
-                                FUN = segments, ...)
+                                FUN = segments, col[match(is, inds)],
+                                lty = lty[match(is,inds)],
+                                lwd = lwd[match(is,inds)],...)
             } else {
                 ave <- X
             }
@@ -61,7 +78,7 @@
             }
         }
     }
-    if (label) 
+    if (label)
         ordiArgAbsorber(cntrs, label = names, FUN = ordilabel, ...)
     spids <- t(spids)
     class(spids) <- "ordispider"
