@@ -49,7 +49,8 @@ C---      iax=ifix((x(i)-axmin)/axbit)+3
       iax=int((x(i)-axmin)/axbit)+3
       if(iax.lt.3) iax=3
       if(iax.gt.maxk) iax=maxk
-   10 ix(i)=iax
+      ix(i)=iax
+ 10   continue
       return
       end
 c
@@ -73,7 +74,8 @@ c them (in the case of reciprocal averaging).
       integer ix1(mi),ix2(mi),ix3(mi),idat(nid),ibegin(mi),iend(mi)
       call yxmult(y,x,mi,n,nid,ibegin,iend,idat,qidat)
       do 10 i=1,mi
-   10 x(i)=x(i)/aidot(i)
+      x(i)=x(i)/aidot(i)
+ 10   continue
       if(neig.eq.0) goto 200
       if(ira.eq.1) goto 100
       call detrnd(x,aidot,ix1,mi,mk)
@@ -86,21 +88,27 @@ c them (in the case of reciprocal averaging).
       goto 200
   100 a1=0.0
       do 110 i=1,mi
-  110 a1=a1+aidot(i)*x(i)*xeig1(i)
+      a1=a1+aidot(i)*x(i)*xeig1(i)
+ 110  continue
       do 120 i=1,mi
-  120 x(i)=x(i)-a1*xeig1(i)
+      x(i)=x(i)-a1*xeig1(i)
+ 120  continue
       if(neig.eq.1) goto 200
       a2=0.0
       do 130 i=1,mi
-  130 a2=a2+aidot(i)*x(i)*xeig2(i)
+      a2=a2+aidot(i)*x(i)*xeig2(i)
+ 130  continue
       do 140 i=1,mi
-  140 x(i)=x(i)-a2*xeig2(i)
+      x(i)=x(i)-a2*xeig2(i)
+ 140  continue
       if(neig.eq.2) goto 200
       a3=0.0
       do 150 i=1,mi
-  150 a3=a3+aidot(i)*x(i)*xeig3(i)
+      a3=a3+aidot(i)*x(i)*xeig3(i)
+ 150  continue
       do 160 i=1,mi
-  160 x(i)=x(i)-a3*xeig3(i)
+      x(i)=x(i)-a3*xeig3(i)
+ 160  continue
   200 call xymult(x,yy,mi,n,nid,ibegin,iend,idat,qidat)
       return
       end
@@ -116,20 +124,25 @@ c can be obtained, corresponding to 3 possible starting positions
 c for the blocks of 3.
       do 10 k=1,mk
       z(k)=0.0
-   10 zn(k)=0.0
+      zn(k)=0.0
+ 10   continue
       do 20 i=1,mi
       k=ix(i)
       z(k)=z(k)+x(i)*aidot(i)
-   20 zn(k)=zn(k)+aidot(i)
+      zn(k)=zn(k)+aidot(i)
+ 20   continue
       mmk=mk-1
       do 30 k=2,mmk
-   30 zbar(k)=(z(k-1)+z(k)+z(k+1))/(zn(k-1)+zn(k)+zn(k+1)+1.0e-12)
+      zbar(k)=(z(k-1)+z(k)+z(k+1))/(zn(k-1)+zn(k)+zn(k+1)+1.0e-12)
+ 30   continue
       mmk=mmk-1
       do 35 k=3,mmk
-   35 z(k)=(zbar(k-1)+zbar(k)+zbar(k+1))/3.0
+      z(k)=(zbar(k-1)+zbar(k)+zbar(k+1))/3.0
+ 35   continue
       do 40 i=1,mi
       k=ix(i)
- 40   x(i)=x(i)-z(k)
+      x(i)=x(i)-z(k)
+ 40   continue
       return
       end
 
@@ -143,21 +156,26 @@ c J. Oksanen 1 Oct, 2010.
       integer ix(mi)
       do 10 k=1,mk
       z(k)=0.0
-   10 zn(k)=0.0
+      zn(k)=0.0
+ 10   continue
       do 20 i=1,mi
       k=ix(i)
       z(k)=z(k)+x(i)*aidot(i)
-   20 zn(k)=zn(k)+aidot(i)
+      zn(k)=zn(k)+aidot(i)
+ 20   continue
       mmk=mk-1
       do 30 k=2,mmk
-   30 zbar(k)=(z(k-1)+z(k)+z(k+1))/(zn(k-1)+zn(k)+zn(k+1)+1.0e-12)
+      zbar(k)=(z(k-1)+z(k)+z(k+1))/(zn(k-1)+zn(k)+zn(k+1)+1.0e-12)
+ 30   continue
       mmk=mmk-1
       do 35 k=3,mmk
-   35 z(k)=(zbar(k-1)+zbar(k)+zbar(k+1))/3.0
+      z(k)=(zbar(k-1)+zbar(k)+zbar(k+1))/3.0
+ 35   continue
       do 40 i=1,mi
       k=ix(i)
       fit(i) = z(k)
-   40 x(i)=x(i)-z(k)
+      x(i)=x(i)-z(k)
+ 40   continue
       return
       end
 c
@@ -178,12 +196,13 @@ c (subroutine strtch).
       double precision qidat(nid)
       integer ibegin(mi),iend(mi),idat(nid),ix1(mi),ix2(mi),ix3(mi)
 c strings to print R warnings
-      character*64 warning
-      character*2 axnam
+      character (len=64) warning
+      character (len=2) axnam
       tot=0.0
       do 10 j=1,n
       tot=tot+adotj(j)
-   10 y(j)=float(j)
+      y(j)=float(j)
+ 10   continue
       y(1)=1.1
 c---tolerance reduced by p.minchin jan 1997
 c      tol=0.0001
@@ -194,16 +213,19 @@ c      tol=0.0001
       icount=0
    20 a=0.0
       do 30 j=1,n
-   30 a=a+y(j)*adotj(j)
+      a=a+y(j)*adotj(j)
+ 30   continue
       a=a/tot
       ex=0.0
       do 40 j=1,n
       ay=y(j)-a
       ex=ex+ay*ay*adotj(j)
-   40 y(j)=ay
+      y(j)=ay
+ 40   continue
       ex=sqrt(ex)
       do 50 j=1,n
-   50 y(j)=y(j)/ex
+       y(j)=y(j)/ex
+ 50   continue
       call trans(y,y2,
      1x,neig,ira,aidot,xeig1,xeig2,xeig3,ix1,ix2,ix3,
      2mi,mk,n,nid,ibegin,iend,idat,qidat)
@@ -219,15 +241,18 @@ c      tol=0.0001
       ay=y2(j)
       y2(j)=ay/adotj(j)
       a=a+ay
-   60 a11=a11+ay*y(j)
+      a11=a11+ay*y(j)
+ 60   continue
       a=a/tot
       do 70 j=1,n
       ay=y2(j)-(a+a11*y(j))
       a12=a12+ay*ay*adotj(j)
-   70 y2(j)=ay
+      y2(j)=ay
+ 70   continue
       a12=sqrt(a12)
       do 80 j=1,n
-   80 y2(j)=y2(j)/a12
+      y2(j)=y2(j)/a12
+ 80   continue
 c---------removed write statements--------------------------
 c      if(icount.eq.0) write(*,1000)
 c 1000 format(/1x)
@@ -248,19 +273,22 @@ c      if(icount.gt.9) goto 200
       y3(j)=ay/adotj(j)
       a=a+ay
       a22=a22+ay*y2(j)
-   90 b13=b13+ay*y(j)
+      b13=b13+ay*y(j)
+ 90   continue
       a=a/tot
       do 100 j=1,n
       ay=y3(j)-(a+a22*y2(j)+b13*y(j))
       a23=a23+ay*ay*adotj(j)
-  100 y3(j)=ay
+      y3(j)=ay
+ 100  continue
       a23=sqrt(a23)
       if(a23.gt.tol) goto 105
       a23=0.0
       goto 160
   105 continue
       do 110 j=1,n
-  110 y3(j)=y3(j)/a23
+      y3(j)=y3(j)/a23
+ 110  continue
       call trans(y3,y4,
      1x,neig,ira,aidot,xeig1,xeig2,xeig3,ix1,ix2,ix3,
      2mi,mk,n,nid,ibegin,iend,idat,qidat)
@@ -273,24 +301,28 @@ c      if(icount.gt.9) goto 200
       a=a+ay
       a33=a33+ay*y3(j)
       b14=b14+ay*y(j)
-  120 b24=b24+ay*y2(j)
+      b24=b24+ay*y2(j)
+ 120  continue
       a=a/tot
       do 130 j=1,n
       ay=y4(j)-(a+a33*y3(j)+b14*y(j)+b24*y2(j))
       a34=a34+ay*ay*adotj(j)
-  130 y4(j)=ay
+      y4(j)=ay
+ 130  continue
       a34=sqrt(a34)
       if(a34.gt.tol) goto 135
       a34=0.0
       goto 160
   135 continue
       do 140 j=1,n
-  140 y4(j)=y4(j)/a34
+      y4(j)=y4(j)/a34
+ 140  continue
       call trans(y4,y5,
      1x,neig,ira,aidot,xeig1,xeig2,xeig3,ix1,ix2,ix3,
      2mi,mk,n,nid,ibegin,iend,idat,qidat)
       do 150 j=1,n
-  150 a44=a44+y4(j)*y5(j)
+      a44=a44+y4(j)*y5(j)
+ 150  continue
 c we now have the tridiagonal representation of trans.  solve
 c eigenproblem for tridiagonal matrix.
   160 ax1=1.0
@@ -319,7 +351,8 @@ c eigenproblem for tridiagonal matrix.
   170 continue
   180 continue
       do 190 j=1,n
-  190 y(j)=ax1*y(j)+ax2*y2(j)+ax3*y3(j)+ax4*y4(j)
+      y(j)=ax1*y(j)+ax2*y2(j)+ax3*y3(j)+ax4*y4(j)
+ 190  continue
       goto 20
 c-----------Removed write statements, added 200 continue--------
  200  continue
@@ -344,10 +377,12 @@ c averaging option is in force (ira=1)
       sign=1.0
       if(-aymin.gt.aymax) sign=-1.0
       do 210 j=1,n
-  210 y(j)=y(j)*sign
+      y(j)=y(j)*sign
+ 210  continue
       call yxmult(y,x,mi,n,nid,ibegin,iend,idat,qidat)
       do 220 i=1,mi
-  220 x(i)=x(i)/aidot(i)
+      x(i)=x(i)/aidot(i)
+ 220  continue
       if(iresc.eq.0) goto 225
       if(a11.gt.0.999) goto 225
       do 223 i=1,iresc
@@ -360,12 +395,15 @@ c averaging option is in force (ira=1)
       return
   225 axlong=0.0
       do 230 i=1,mi
-  230 axlong=axlong+aidot(i)*x(i)**2
+      axlong=axlong+aidot(i)*x(i)**2
+ 230  continue
       axlong=sqrt(axlong)
       do 240 i=1,mi
-  240 x(i)=x(i)/axlong
+      x(i)=x(i)/axlong
+ 240  continue
       do 250 j=1,n
-  250 y(j)=y(j)/axlong
+      y(j)=y(j)/axlong
+ 250  continue
 c it remains to scale y to unit within-sample standard deviation
       sumsq=0.0
       do 260 i=1,mi
@@ -374,7 +412,8 @@ c it remains to scale y to unit within-sample standard deviation
       ax=x(i)
       do 255 id=id1,id2
       j=idat(id)
-  255 sumsq=sumsq+qidat(id)*(ax-y(j))**2
+      sumsq=sumsq+qidat(id)*(ax-y(j))**2
+ 255  continue
   260 continue
       sd=sqrt(sumsq/tot)
       if(a11.le.0.999) goto 265
@@ -383,7 +422,8 @@ c it remains to scale y to unit within-sample standard deviation
       if(sd1.gt.sd) sd=sd1
   265 continue
       do 270 j=1,n
-  270 y(j)=y(j)/sd
+      y(j)=y(j)/sd
+ 270  continue
       eig=a11
       return
       end
@@ -394,14 +434,16 @@ c starts with vector x and forms matrix product y=ax
       double precision x(mi),y(n),qidat(nid)
       integer ibegin(mi),iend(mi),idat(nid)
       do 10 j=1,n
-   10 y(j)=0.0
+      y(j)=0.0
+ 10   continue
       do 30 i=1,mi
       id1=ibegin(i)
       id2=iend(i)
       ax=x(i)
       do 20 id=id1,id2
       j=idat(id)
-   20 y(j)=y(j)+ax*qidat(id)
+      y(j)=y(j)+ax*qidat(id)
+ 20   continue
    30 continue
       return
       end
@@ -417,8 +459,10 @@ c starts with vector y and forms matrix product x=ay
       ax=0.0
       do 10 id=id1,id2
       j=idat(id)
-   10 ax=ax+y(j)*qidat(id)
-   20 x(i)=ax
+      ax=ax+y(j)*qidat(id)
+ 10   continue
+      x(i)=ax
+ 20   continue
       return
       end
 c
@@ -459,7 +503,8 @@ c      common /lunits/ iuinp1,iuinp2,iuout1,iuout2,iuout3
       call smooth(zn,mk)
       zvsum=0.0
       do 50 k=1,mk
-   50 zvsum=zvsum+zv(k)/zn(k)
+      zvsum=zvsum+zv(k)/zn(k)
+ 50   continue
       sd=sqrt(zvsum/float(mk))
 c we want mean within-sample square deviation to be 1.0, so we divide
 c everything by sd
@@ -467,14 +512,16 @@ c everything by sd
       do 60 i=1,mi
       ax=x(i)/sd
       x(i)=ax
-   60 if(along.lt.ax) along=ax
+      if(along.lt.ax) along=ax
+ 60   continue
 c--------Removed write statements----------------------------
 c      if(icount.eq.1.and.monit.eq.1) write(*,1000)
 c 1000 format(/1x)
 c      if(monit.eq.1) write(*,1001) along
 c 1001 format(1x,'length of gradient',f10.3)
       do 70 j=1,n
-   70 y(j)=y(j)/sd
+      y(j)=y(j)/sd
+ 70   continue
       if(along.lt.short) return
       if(icount.eq.2) return
 c      mk=ifix(along*5.0)+1
@@ -488,9 +535,11 @@ c      mk=ifix(along*5.0)+1
       do 100 k=1,mk
       azv=1.0/sqrt(0.2/along+zv(k)/zn(k))
       zvsum=zvsum+azv
-  100 zv(k)=azv
+      zv(k)=azv
+ 100  continue
       do 110 k=1,mk
-  110 zv(k)=zv(k)*along/zvsum
+      zv(k)=zv(k)*along/zvsum
+ 110  continue
 c----------Removed write statements-------------------------
 c      if(monit.eq.1) write(*,1002) (zv(k),k=1,mk)
 c 1002 format(1x,'length of segments',10f6.2)
@@ -498,17 +547,20 @@ c 1002 format(1x,'length of segments',10f6.2)
       zn(1)=0.0
       do 120 k=1,mk
       az=az+zv(k)
-  120 zn(k+1)=az
+      zn(k+1)=az
+ 120  continue
       axbit=along/float(mk)
       do 130 j=1,n
 C      iay=ifix(y(j)/axbit)+1
       iay=int(y(j)/axbit)+1
       if(iay.lt.1) iay=1
       if(iay.gt.mk) iay=mk
-  130 y(j)=zn(iay)+zv(iay)*(y(j)/axbit-float(iay-1))
+      y(j)=zn(iay)+zv(iay)*(y(j)/axbit-float(iay-1))
+ 130  continue
       call yxmult(y,x,mi,n,nid,ibegin,iend,idat,qidat)
       do 140 i=1,mi
-  140 x(i)=x(i)/aidot(i)
+      x(i)=x(i)/aidot(i)
+ 140  continue
   200 continue
       return
       end
@@ -533,7 +585,8 @@ c 15,6,1)-smoothing.
 c---bug in next line fixed by p.minchin jan 1997
 c      if(az3.lt.0.0) istop=0
       if(az3.le.0.0) istop=0
-   10 z(k3-1)=0.5*(az2+0.5*(az1+az3))
+      z(k3-1)=0.5*(az2+0.5*(az1+az3))
+ 10   continue
       z(mk)=0.25*az2+0.75*az3
       istop=istop+1
       if(istop.eq.4) goto 30
@@ -552,13 +605,16 @@ c zn as nearly equal as possible.)
       integer ibegin(mi),iend(mi),idat(nid)
       do 10 k=1,mk
       zn(k)=-1.0e-20
-   10 zv(k)=-1.0e-20
+      zv(k)=-1.0e-20
+ 10   continue
       call xmaxmi(x,axmax,axmin,mi)
       axbit=(axmax-axmin)/float(mk)
       do 20 i=1,mi
-   20 x(i)=x(i)-axmin
+      x(i)=x(i)-axmin
+ 20   continue
       do 30 j=1,n
-   30 y(j)=y(j)-axmin
+      y(j)=y(j)-axmin
+ 30   continue
       do 50 i=1,mi
       sqcorr=0.0
       sumsq=2.0e-20
@@ -569,7 +625,8 @@ c zn as nearly equal as possible.)
       j=idat(id)
       aij=qidat(id)
       sqcorr=sqcorr+aij**2
-   40 sumsq=sumsq+aij*(ax-y(j))**2
+      sumsq=sumsq+aij*(ax-y(j))**2
+ 40   continue
       sqcorr=sqcorr/aidot(i)**2
       if(sqcorr.gt.0.9999) sqcorr=0.9999
       sumsq=sumsq/aidot(i)
