@@ -43,6 +43,8 @@
 #define MILLAR 12
 #define CHAO 13
 #define GOWERDZ 14
+#define CAO 15
+#define MAHALANOBIS 16
 #define MATCHING 50
 #define NOSHARED 99
 
@@ -58,7 +60,7 @@ double veg_manhattan(double *x, int nr, int nc, int i1, int i2)
      dist = 0.0;
      count = 0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       dist += fabs( x[i1] - x[i2] );
 	       count++;
 	  }
@@ -83,7 +85,7 @@ double veg_gower(double *x, int nr, int nc, int i1, int i2)
      dist = 0.0;
      count = 0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       dist += fabs( x[i1] - x[i2] );
 	       count++;
 	  }
@@ -110,7 +112,7 @@ double veg_gowerDZ(double *x, int nr, int nc, int i1, int i2)
      dist = 0.0;
      count = 0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	      if (x[i1] > 0 || x[i2] > 0) {
 		  dist += fabs( x[i1] - x[i2] );
 		  count++;
@@ -124,7 +126,9 @@ double veg_gowerDZ(double *x, int nr, int nc, int i1, int i2)
      return dist;
 }
 
-/* Euclidean distance: duplicates base R */
+/* Euclidean distance: duplicates base R. If Mahalanobis
+ * transformation was performred in the calling routine, this will
+ * give Mahalanobis distances. */
 
 double veg_euclidean(double *x, int nr, int nc, int i1, int i2)
 {
@@ -134,7 +138,7 @@ double veg_euclidean(double *x, int nr, int nc, int i1, int i2)
      count = 0;
      dist = 0.0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       dev = x[i1] - x[i2];
 	       dist += dev*dev;
 	       count++;
@@ -158,7 +162,7 @@ double veg_canberra(double *x, int nr, int nc, int i1, int i2)
      count = 0;
      dist = 0.0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       if (x[i1] != 0 || x[i2] != 0) {
 		    count++;
 		    denom = x[i1] + x[i2];
@@ -196,7 +200,7 @@ double veg_bray(double *x, int nr, int nc, int i1, int i2)
      count = 0;
      dist = 0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       dist += fabs(x[i1] - x[i2]);
 	       total += x[i1] + x[i2];
 	       count++;
@@ -221,7 +225,7 @@ double veg_kulczynski(double *x, int nr, int nc, int i1, int i2)
      count = 0;
      sim = 0.0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       sim += (x[i1] < x[i2]) ? x[i1] : x[i2] ;
 	       t1 += x[i1];
 	       t2 += x[i2];
@@ -253,7 +257,7 @@ double veg_morisita(double *x, int nr, int nc, int i1, int i2)
      tlam1 = 0.0;
      tlam2 = 0.0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       sim += x[i1]*x[i2];
 	       t1 += x[i1];
 	       t2 += x[i2];
@@ -285,7 +289,7 @@ double veg_horn(double *x, int nr, int nc, int i1, int i2)
      sq1 = 0.0;
      sq2 = 0.0;
      for (j=0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       sim += x[i1]*x[i2];
 	       t1 += x[i1];
 	       t2 += x[i2];
@@ -335,7 +339,7 @@ double veg_mountford(double *x, int nr, int nc, int i1, int i2)
      t2 = 0;
      count = 0;
      for (j = 0; j < nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       if (x[i1] > 0.0 && x[i2] > 0.0)
 		    sim++;
 	       if (x[i1] > 0)
@@ -403,7 +407,7 @@ double veg_raup(double *x, int nr, int nc, int i1, int i2)
 	t2 = 0;
 	count = 0;
 	for (j = 0; j < nc; j++) {
-		if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+		if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 			if (x[i1] > 0.0 && x[i2] > 0.0)
 				sim++;
 			if (x[i1] > 0)
@@ -439,7 +443,7 @@ double veg_millar(double *x, int nr, int nc, int i1, int i2)
      count = 0;
      dist = 0;
      for (j=0; j<nc; j++, i1 += nr, i2 += nr) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       nk = x[i1] + x[i2];
 	       if (nk == 0) continue;
 	       lognk = log(nk);
@@ -478,7 +482,7 @@ double veg_chao(double *x, int nr, int nc, int i1, int i2)
     jshar1 = 0;
     count = 0;
     for (j=0; j<nc; j++) {
-	if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	    count++;
 	    itot += x[i1];
 	    jtot += x[i2];
@@ -526,6 +530,46 @@ double veg_chao(double *x, int nr, int nc, int i1, int i2)
     return dist;
 }
 
+/* veg_cao implements Cao index (CYd) of Cao Y, Williams WP, Bark AW:
+ *   Water Envir Res 69, 95-106; 1997. Anderson MJ & Thompson AA: Ecol
+ *   Appl 14, 1921-1935; 2004 use different but equal formulation.
+ */
+
+double veg_cao(double *x, int nr, int nc, int i1, int i2)
+{
+     double dist, x1, x2, t1, t2;
+     int count, j;
+  
+     count = 0;
+     dist = 0;
+     for (j=0; j<nc; j++, i1 += nr, i2 += nr) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
+	       /* skip the rest of the loop if both species are
+		  absent */
+	       if (x[i1] == 0 && x[i2] == 0) continue;
+	       /* Cao uses arbitrary value of 0.1 for zeros to avoid
+		  log(0). Obviously this indicates the use of counts
+		  (integer), but we accept non-integer data (with a
+		  warning in R) and put the truncation to the same 0.1
+		  to avoid discontinuities with non-integer data */
+	       x1 = (x[i1] < 0.1) ? 0.1 : x[i1];
+	       x2 = (x[i2] < 0.1) ? 0.1 : x[i2];
+	       t1 = x1 + x2;
+	       /* Cao et al. used log10, but we do not and so our
+		  results are log(10) = 2.302585 times higher */
+	       t2 = x1 * log(x2) + x2 * log(x1);
+	       dist += log(t1) - M_LN2 - t2/t1;
+	       count++;
+	  }
+     }
+     if (count==0) return NA_REAL;
+     if (dist < 0)
+	 dist = 0;
+     dist /= (double)count;
+     return dist;
+}
+
+
 /* veg_noshared is not a proper dissimilarity index, but a pretty
  * useless helper function. It returns 1 when there are no shared
  * species, and 0 if two sites have at least one shared species, and
@@ -540,7 +584,7 @@ double veg_noshared(double *x, int nr, int nc, int i1, int i2)
      dist = 1;
      count = 0;
      for (j = 0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       count++;
 	       if (x[i1] > 0 && x[i2] > 0) {
 		    dist = 0;
@@ -565,7 +609,7 @@ double veg_matching(double *x, int nr, int nc, int i1, int i2)
      matches = 0;
      count = 0;
      for (j = 0; j<nc; j++) {
-	  if (R_FINITE(x[i1]) && R_FINITE(x[i2])) {
+	  if (!ISNAN(x[i1]) && !ISNAN(x[i2])) {
 	       count++;
 	       if (x[i1] == x[i2])
 		    matches++;
@@ -590,6 +634,7 @@ void veg_distance(double *x, int *nr, int *nc, double *d, int *diag, int *method
 	distfun = veg_manhattan;
 	break;
     case EUCLIDEAN:
+    case MAHALANOBIS:
 	distfun = veg_euclidean;
 	break;
     case CANBERRA:
@@ -626,6 +671,9 @@ void veg_distance(double *x, int *nr, int *nc, double *d, int *diag, int *method
     case GOWERDZ:
 	distfun = veg_gowerDZ;
 	break;
+    case CAO:
+        distfun = veg_cao;
+        break;
     case MATCHING:
 	distfun = veg_matching;
 	break;
